/*
 *  Copyright (c) Members of the EGEE Collaboration. 2005.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  gLite Data Management - Simple channel management API
 *
 *  Authors:
 *      Zsolt Molnar <Zsolt.Molnar@cern.ch>
 */

#include "../../axis/adb_CannotCancelException.h"
#include "fts_soap_exception_api_impl.h"
#include "fts_exception_factory.h"

fts_exception_t* _fts_create_exception_CannotCancelException(fts_xml_repr_t *detail, const axutil_env_t *env)
{
    fts_exception_t *exception = NULL;
    fts_xml_repr_t *exception_xml = _fts_get_exception_xml("CannotCancelException", env, detail);

    if (exception_xml) {
        axis2_status_t deserialize_status = AXIS2_FAILURE;
        adb_CannotCancelException_t *obj = adb_CannotCancelException_create(env);
        assert(obj);

        if (obj)
            deserialize_status = adb_CannotCancelException_deserialize(
                    obj, env, fts_xml_repr_node_ref(exception_xml), NULL, AXIS2_FALSE);

        if (deserialize_status == AXIS2_SUCCESS)
            exception = fts_exception_create(env, fts_exception_CannotCancelException_id, obj, 
                _fts_exception_free_CannotCancelException, _fts_exception_get_message_CannotCancelException,
                _fts_exception_get_name_CannotCancelException);
    }

    fts_xml_repr_free(exception_xml, env);
    return exception;
}

void _fts_exception_free_CannotCancelException(fts_exception_t *self)
{
    assert(self);
    const axutil_env_t *env = fts_exception_get_env(self);
    assert(env);
    
    if (self && env) {
        adb_CannotCancelException_t* obj = (adb_CannotCancelException_t*)(fts_exception_get_object(self));
        adb_CannotCancelException_free(obj, env);
    }
}

const char* _fts_exception_get_message_CannotCancelException(const fts_exception_t *self)
{
    assert(self);
    const axutil_env_t *env = fts_exception_get_env(self);
    adb_CannotCancelException_t* obj = (adb_CannotCancelException_t*)(fts_exception_get_object(self));
    assert(env);
    assert(obj);
    const char* message = NULL;
    
    if (self && obj && env) {
        adb_TCannotCancelException_t* real_object = adb_CannotCancelException_get_CannotCancelException(obj, env);
        assert(real_object);
        
        if (real_object && 
            !adb_TCannotCancelException_is_message_nil(real_object, env))
        {
            message = adb_TCannotCancelException_get_message(real_object, env);
        }
    }

    return message;    
}

const char* _fts_exception_get_name_CannotCancelException(void)
{
    return "CannotCancelException";
}

