/*
 *  Copyright (c) Members of the EGEE Collaboration. 2005.
 *  See http://eu-egee.org/partners/ for details on the copyright holders.
 *  For license conditions see the license file or http://eu-egee.org/license.html
 *
 *  gLite Data Management - Simple channel management API
 *
 *  Authors:
 *      Zsolt Molnar <Zsolt.Molnar@cern.ch>
 */

#include <stdlib.h>

#include "fts_xml_repr.h"

struct fts_xml_repr
{
	axiom_node_t *node;
	axiom_element_t *element;
};

fts_xml_repr_t* fts_xml_repr_create(axiom_node_t *node, axiom_element_t *element)
{
	fts_xml_repr_t* self = calloc(1, sizeof(fts_xml_repr_t));
	assert(self);

	if (self) {
		self->node = node;
		self->element = element;
	}

	return self;
}

void fts_xml_repr_free(fts_xml_repr_t* self, const axutil_env_t* env)
{
	if (self) {
		axiom_node_free_tree(self->node, env);
		free(self);
	}
}

axiom_node_t* fts_xml_repr_node(fts_xml_repr_t* self)
{
	assert(self);
	return self ? self->node : NULL;
}

axiom_node_t** fts_xml_repr_node_ref(fts_xml_repr_t* self)
{
	assert(self);
	/* Here, self MUST not be null... */
	return &self->node;
}

axiom_element_t* fts_xml_repr_element(fts_xml_repr_t* self)
{
	assert(self);
	return self ? self->element : NULL;
}

int fts_xml_repr_is_valid(fts_xml_repr_t* self)
{
	return self && self->node && self->element;
}
